@@ -34,15 +34,13 @@ class Face:
 
 
 class FaceAnalysis:
-    def __init__(self, *, model_path=None, det_model_name='scrfd_10g_bnkps', rec_model_name='glintr100'):
+    def __init__(self, *, model_path, det_model_name='scrfd_10g_bnkps', rec_model_name='glintr100'):
         """
         :param model_path: 模型路径
         :param det_model_name: 人脸检测模型名称
         :param rec_model_name: 人脸识别模型名称
 
         """
-        if model_path is None:
-            model_path = os.path.join(os.path.dirname(__file__), 'models')
         self.det_model = SCRFD(os.path.join(model_path, "antelope", "%s.onnx" % det_model_name))
         if rec_model_name is not None:
             self.rec_model = ArcFace(os.path.join(model_path, "antelope", "%s.onnx" % rec_model_name))
